@@ -361,8 +361,9 @@ class CalibrationSequence():
 
         for i in range(self.numsteps):
             if self.pol_in[i]:
-                rot_in = Data.rotation(self.theta_pol_steps[i])
-                rot_out = Data.rotation(-self.theta_pol_steps[i])
+                theta_pol = -self.theta_pol_steps[i] + np.pi / 2.  # Header/213 coordinate conversion
+                rot_in = Data.rotation(theta_pol)
+                rot_out = Data.rotation(-theta_pol)
 
                 pol_mat[i] = rot_out @ Data.polarizer(t_pol[i], self.py) @ rot_in
             else:
@@ -387,8 +388,9 @@ class CalibrationSequence():
 
         for i in range(self.numsteps):
             if self.ret_in[i]:
-                rot_in = Data.rotation(self.theta_ret_steps[i])
-                rot_out = Data.rotation(-self.theta_ret_steps[i])
+                theta_ret = -self.theta_ret_steps[i]  # Header/213 coordinate conversion
+                rot_in = Data.rotation(theta_ret)
+                rot_out = Data.rotation(-theta_ret)
                 ret_mat[i] = rot_out @ Data.elliptical_retarder(t_ret[i], ret_h[i], ret_45[i], ret_r[i]) @ rot_in
             else:
                 ret_mat[i] = np.diag(np.ones(4, dtype=np.float64))
