@@ -10,6 +10,9 @@ from dkist_processing_pac.tag import tag
 
 
 class DCDrawer(Drawer):
+    """
+    A wrapper that provides and interface that can be used by DKISTDC automated-processing pipelines
+    """
 
     def __init__(self, fits_access_dict, skip_darks=True, remove_I_trend=True):
         super().__init__(data_dir=None, suffix='', remove_I_trend=False)
@@ -27,7 +30,12 @@ class DCDrawer(Drawer):
         In addition to loading the actual data, header values are also inspected to create vectors of the polarizer and
         retarder angles, telescope geometry, and observation times.
 
-        skip_darks : bool
+        Parameters
+        ----------
+        raw_fits_access
+            Dict where keys are the CS step number and values are a list of FitsAccess objects
+
+        skip_darks
             If True (default) then don't load any dark steps from the CS
         """
         inst_set = set()
@@ -87,9 +95,9 @@ class DCDrawer(Drawer):
     def __getitem__(self, item):
         """This builtin method provides the mechanism by which the object can be sliced to provided a single SoCC.
 
-        The slice must have two elements (x, y, l). E.g.:
+        The slice must have three elements (x, y, l). E.g.:
 
-        >>> I = DRWR[x, y, l]
+            >>> I = DRWR[x, y, l]
 
         Parameters
         ----------
